==> istio-model-v1beta1-6.5.0-sources.jar: io/fabric8/istio/api/security/v1beta1/RequestAuthenticationSpecFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelector;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluent;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface RequestAuthenticationSpecFluent<A extends RequestAuthenticationSpecFluent<A>> extends Fluent<A>{
  public A addToJwtRules(Integer index,JWTRule item);
  public A setToJwtRules(Integer index,JWTRule item);
  public A addToJwtRules(io.fabric8.istio.api.security.v1beta1.JWTRule... items);
  public A addAllToJwtRules(Collection<JWTRule> items);
  public A removeFromJwtRules(io.fabric8.istio.api.security.v1beta1.JWTRule... items);
  public A removeAllFromJwtRules(Collection<JWTRule> items);
  public A removeMatchingFromJwtRules(Predicate<JWTRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildJwtRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<JWTRule> getJwtRules();
  public List<JWTRule> buildJwtRules();
  public JWTRule buildJwtRule(Integer index);
  public JWTRule buildFirstJwtRule();
  public JWTRule buildLastJwtRule();
  public JWTRule buildMatchingJwtRule(Predicate<JWTRuleBuilder> predicate);
  public Boolean hasMatchingJwtRule(Predicate<JWTRuleBuilder> predicate);
  public A withJwtRules(List<JWTRule> jwtRules);
  public A withJwtRules(io.fabric8.istio.api.security.v1beta1.JWTRule... jwtRules);
  public Boolean hasJwtRules();
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> addNewJwtRule();
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> addNewJwtRuleLike(JWTRule item);
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> setNewJwtRuleLike(Integer index,JWTRule item);
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> editJwtRule(Integer index);
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> editFirstJwtRule();
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> editLastJwtRule();
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> editMatchingJwtRule(Predicate<JWTRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadSelector getSelector();
  public WorkloadSelector buildSelector();
  public A withSelector(WorkloadSelector selector);
  public Boolean hasSelector();
  public RequestAuthenticationSpecFluent.TypeSelectorNested<A> withNewTypeSelector();
  public RequestAuthenticationSpecFluent.TypeSelectorNested<A> withNewSelectorLike(WorkloadSelector item);
  public RequestAuthenticationSpecFluent.TypeSelectorNested<A> editTypeSelector();
  public RequestAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelector();
  public RequestAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelectorLike(WorkloadSelector item);
  public interface JwtRulesNested<N> extends Nested<N>,JWTRuleFluent<RequestAuthenticationSpecFluent.JwtRulesNested<N>>{
    public N and();
    public N endJwtRule();
    
  }
  public interface TypeSelectorNested<N> extends Nested<N>,WorkloadSelectorFluent<RequestAuthenticationSpecFluent.TypeSelectorNested<N>>{
    public N and();
    public N endTypeSelector();
    
  }
  
}

==> istio-model-v1beta1-6.7.2-sources.jar: io/fabric8/istio/api/security/v1beta1/RequestAuthenticationSpecFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelector;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluent;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface RequestAuthenticationSpecFluent<A extends RequestAuthenticationSpecFluent<A>> extends Fluent<A>{
  public A addToJwtRules(int index,JWTRule item);
  public A setToJwtRules(int index,JWTRule item);
  public A addToJwtRules(io.fabric8.istio.api.security.v1beta1.JWTRule... items);
  public A addAllToJwtRules(Collection<JWTRule> items);
  public A removeFromJwtRules(io.fabric8.istio.api.security.v1beta1.JWTRule... items);
  public A removeAllFromJwtRules(Collection<JWTRule> items);
  public A removeMatchingFromJwtRules(Predicate<JWTRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildJwtRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<JWTRule> getJwtRules();
  public List<JWTRule> buildJwtRules();
  public JWTRule buildJwtRule(int index);
  public JWTRule buildFirstJwtRule();
  public JWTRule buildLastJwtRule();
  public JWTRule buildMatchingJwtRule(Predicate<JWTRuleBuilder> predicate);
  public Boolean hasMatchingJwtRule(Predicate<JWTRuleBuilder> predicate);
  public A withJwtRules(List<JWTRule> jwtRules);
  public A withJwtRules(io.fabric8.istio.api.security.v1beta1.JWTRule... jwtRules);
  public Boolean hasJwtRules();
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> addNewJwtRule();
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> addNewJwtRuleLike(JWTRule item);
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> setNewJwtRuleLike(int index,JWTRule item);
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> editJwtRule(int index);
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> editFirstJwtRule();
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> editLastJwtRule();
  public RequestAuthenticationSpecFluent.JwtRulesNested<A> editMatchingJwtRule(Predicate<JWTRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadSelector getSelector();
  public WorkloadSelector buildSelector();
  public A withSelector(WorkloadSelector selector);
  public Boolean hasSelector();
  public RequestAuthenticationSpecFluent.TypeSelectorNested<A> withNewTypeSelector();
  public RequestAuthenticationSpecFluent.TypeSelectorNested<A> withNewSelectorLike(WorkloadSelector item);
  public RequestAuthenticationSpecFluent.TypeSelectorNested<A> editTypeSelector();
  public RequestAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelector();
  public RequestAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelectorLike(WorkloadSelector item);
  public interface JwtRulesNested<N> extends Nested<N>,JWTRuleFluent<RequestAuthenticationSpecFluent.JwtRulesNested<N>>{
    public N and();
    public N endJwtRule();
    
  }
  public interface TypeSelectorNested<N> extends Nested<N>,WorkloadSelectorFluent<RequestAuthenticationSpecFluent.TypeSelectorNested<N>>{
    public N and();
    public N endTypeSelector();
    
  }
  
}
